create_iced_editor

Function create_iced_editor 

pub fn create_iced_editor<P, B, EState>(
    window_state: Arc<WindowState>,
    editor_state: EState,
    notifier: PollSubNotifier,
    settings: EditorSettings,
    build: B,
) -> Option<Box<dyn Editor>>
where P: Program + 'static, B: Fn(EditorState<EState>, NiceGuiContext) -> P + 'static + Send + Sync, EState: Send + 'static,
Create a new Editor using the Iced GUI framework.

  • window_state - The initial window state.
  • editor_state - Custom state which persists between editor opens.
  • notifier - An atomic flag used to notify the program when it should poll for new updates and redraw (i.e. as a result of the host updating parameters or the audio thread updating the state of meters). This flag is polled every frame right before drawing. If the flag is set then the poll_events subscription will be called.
  • settings - Additional settings for the editor.
  • build - The function which builds the Iced program.