WindowState

Struct WindowState 

pub struct WindowState { /* private fields */ }
State for an nice-plug-iced editor window.

Implementations

Source

impl WindowState

pub fn from_logical_size(width: u32, height: u32) -> Arc<WindowState>

Initialize the GUI’s state. This value can be passed to create_iced_editor(). The window size is in logical pixels, so before it is multiplied by the DPI scaling factor.

pub fn logical_size(&self) -> (u32, u32)

Returns a (width, height) pair for the current size of the GUI in logical pixels.

pub fn is_open(&self) -> bool

Whether the GUI is currently visible.

pub fn set_requested_logical_size(&self, new_size: (u32, u32))

Set the new size that will be used to resize the window if the host allows.